@@ -15,11 +15,20 @@ import json
 import math
 import random
 import string
+import time
 from typing import List, Union
 
 from gitopenlib.utils import basics as gb
 
 
+def fmt_seconds(seconds: int or float, lang: str = "zh"):
+    """把秒转换为小时分钟秒。"""
+    if lang == "zh":
+        return time.strftime("%H小时%M分钟%S秒", time.gmtime(seconds))
+    else:
+        return time.strftime("%H:%M:%S", time.gmtime(seconds))
+
+
 def generate_random_strs(length: int):
     """生成随机字符串"""
     return "".join(random.sample(string.digits * 5 + string.ascii_letters * 4, length))
